/* $Workfile: OsaThrd.h $   $Revision: 5 $    $Modtime: 1/30/02 11:33a $  */
#ifndef OSA_TRHD_H
#define OSA_TRHD_H
/*******************************************************************************

  @doc PublicHwApi OsaThrd

  Copyright (C) 1999 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OsaThrd | This file contains prototypes for platform the
  generic implementation of some thread and mutex functions.

  @contents2
  OsaThrd.h |

  @index func | OsaThrd

  @contents2
  Generic Thread and Mutex Functions - OsaThreadXXX()/OsaMutexXXX() | A platform 
  generic implementation of some thread and mutex functions.
  
  @head3 OsaThreadXXX()/OsaMutexXXX() Function Reference |

  @index func | OsaThrd

*******************************************************************************/

#if defined(__cplusplus)
extern "C" {
#endif

#if defined(__linux__)
#include <pthread.h>
#include "Linux/OsaLinuxThrd.h"

#elif defined(_WIN32_WCE)
#include <windows.h>
#include "WindowsCe/OsaWindowsCeThrd.h"

#elif defined(WIN32)
#include <windows.h>
#include "W32/OsaWin32Thrd.h"

#else

#error "Platform not supported"

#endif

typedef void * (*OsaThreadFnP)(void *pContext);

/******************************************************************************

  @func
    Platform generic Osa implementation of the Win32 Sleep() function.

  @comm
    Osa functions are used by the demo programs.

  @xref
    <f OsaConsoleInit>

******************************************************************************/
void OsaThreadSleep(
  unsigned long nMilliSecs  // @parm Sleep time in milliseconds 
);


/******************************************************************************

  @func
    Platform generic Osa implementation of the Win32 CreateThread() function.

  @comm
    Osa functions are used by the demo programs.

  @xref
    <f OsaConsoleInit>

******************************************************************************/
void OsaThreadStart(
  OsaThreadFnP pfnThreadFunc   // @parm Thread function to be started
);


/******************************************************************************

  @func
    Platform generic Osa implementation of the Win32 CreateThread() function.

  @comm
    Osa functions are used by the demo programs.

  @xref
    <f OsaConsoleInit>

******************************************************************************/
void OsaThreadStartEx(
  OsaThreadFnP pfnThreadFunc,  // @parm Thread function to be started
  void *lpParameter            // @parm Parameter to be passed to the thread
);


/******************************************************************************

  @func
    Initalize a Mutex that can be used to create a critical section.

  @comm
    Osa functions are used by the demo programs.

  @xref
    <f OsaConsoleInit>
    <f OsaMutexLock>
    <f OsaMutexUnlock>

******************************************************************************/
void OsaMutexInit(
  OsaMutexS *pMutex    // @parm Pointer to the mutex created by this function call
);


/******************************************************************************

  @func
    Starts a critical section.

  @comm
    Osa functions are used by the demo programs.

  @xref
    <f OsaConsoleInit>
    <f OsaMutexInit>
    <f OsaMutexUnlock>

******************************************************************************/
void OsaMutexLock(
  OsaMutexS *pMutex    // @parm Pointer to the mutex created by a call to <f OsaMutexInit>
);


/******************************************************************************

  @func
    Ends a critical section

  @comm
    Osa functions are used by the demo programs.

  @xref
    <f OsaConsoleInit>
    <f OsaMutexLock>

******************************************************************************/
void OsaMutexUnlock(
  OsaMutexS *pMutex   // @parm Pointer to the mutex created by a call to <f OsaMutexInit>
);


/******************************************************************************

  @func
    Deletes a Mutex created by <f OsaMutexInit>

  @comm
    Osa functions are used by the demo programs.

  @xref
    <f OsaConsoleInit>
    <f OsaMutexInit>

******************************************************************************/
void OsaMutexDestroy(
  OsaMutexS *pMutex   // @parm Pointer to the mutex created by a call to <f OsaMutexInit>
);


#ifdef __cplusplus
  } // extern "C"
#endif

/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1999

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/

#endif // OSA_TRHD_H
