/* $Workfile: OtxBurst.h $   $Revision: 3 $    $Modtime: 12/13/03 12:33p $  */
#ifndef OTX_BURST_H
#define OTX_BURST_H
/*******************************************************************************

  @doc PublicHwApi OtxBurst

  Copyright (C) 2003 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxBurst | Prototypes for the Logical DMA Burst Device (Sender/Receiver) Functions

  @contents2
  OtxBurst.h |

  @index func | OtxBurst

  @contents2
  OTX Logical DMA Burst Sender/Receiver Functions - OtxBurstXXX() | The API functions for the Logical DMA Burst device

  @head3 OtxBurstXXX() Function Reference |

  @index func | OtxBurst

*******************************************************************************/

#ifdef __cplusplus
  extern "C" {
#endif

#include "OtxType.h"
#include "OtxDef.h"

/*******************************************************************************

  @func
    Burst Device direct send.

  @comm
    Send a buffer that is filled with data for an entire frame (32 TS)
    for all LIs hosted by the given highway.

  @xref

*******************************************************************************/
OTX_RESULT OtxBurstSendData(
  IN OTX_HANDLE   hBurstDevice,               // @parm Handle to logical Burst Device
  IN OTX_UINT32   nHighwayNo,                 // @parm Highway number (0 - highway count)
  IN void         *psqData,                   // @parm buffer to send - entire frame of 32 TS for all LIs per highway
  IN OTX_UINT32   *nDataLen                   // @parm buffer size (multiple of number of TS on highway) - upon return the amount of data buffered
);


/*******************************************************************************

  @func
    Burst Device direct receive.

  @comm
    Receive a buffer that is filled with data for an entire frame (32 TS)
    for all LIs hosted by the given highway.  This routine will return
    when the buffer is filled.

  @xref

*******************************************************************************/
OTX_RESULT OtxBurstReceiveData(
  IN OTX_HANDLE   hBurstDevice,               // @parm Handle to logical Burst Device
  IN OTX_UINT32   nHighwayNo,                 // @parm Highway number (0 - highway count)
  IN void         *psqData,                   // @parm buffer to receive - entire frame of 32 TS for all LIs per highway
  IN OTX_UINT32   *nDataLen                   // @parm buffer size (multiple of number of TS on highway) - upon return the amount of data read
);


#ifdef __cplusplus
  } // extern "C"
#endif


/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 2003

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif // OTX_BURST_H
